Index: src/images/SkImageDecoder_FactoryDefault.cpp |
diff --git a/src/images/SkImageDecoder_FactoryDefault.cpp b/src/images/SkImageDecoder_FactoryDefault.cpp |
index e959c8b69b8144ca0b501e77fd8d5a0e965e9a8a..77c0a0ac578ffc3fd20bd8312472c08db91f05db 100644 |
--- a/src/images/SkImageDecoder_FactoryDefault.cpp |
+++ b/src/images/SkImageDecoder_FactoryDefault.cpp |
@@ -27,10 +27,10 @@ SkMovie* SkMovie::DecodeStream(SkStreamRewindable* stream) { |
if (movie) { |
return movie; |
} |
// we must rewind only if we got NULL, since we gave the stream to the |
// movie, who may have already started reading from it |
stream->rewind(); |
curr = curr->next(); |
} |
- return NULL; |
+ return nullptr; |
} |
@@ -27,10 +27,10 @@ SkMovie* SkMovie::DecodeStream(SkStreamRewindable* stream) { |
return movie; |
} |
- // we must rewind only if we got NULL, since we gave the stream to the |
+ // we must rewind only if we got nullptr, since we gave the stream to the |
// movie, who may have already started reading from it |
stream->rewind(); |